@@ -1,5 +1,5 @@
 package HTTP::API::Client;
-$HTTP::API::Client::VERSION = '0.04';
+$HTTP::API::Client::VERSION = '0.05';
 use strict;
 use warnings;
 
@@ -26,13 +26,22 @@ Example:
 
 Get Json Data - grab the content body from the response and json decode
 
- my $data = $ua->json_response;
+ $ua = HTTP::API::Client->new(base_url => URI->new("http://google.com"));
+ $ua->get("/search" => { q => "something" });
+ my $hashref_from_decoded_json_string = $ua->json_response;
+ ## ps. this is just an example to get json from a rest api
+
+Send a query string to server
+
+ $ua = HTTP::API::Client->new( content_type => "application/x-www-form-urlencoded" );
+ $ua->post("http://google.com", { q => "something" });
+ my $response = $ua->last_response; ## is a HTTP::Response object
 
 At the moment, only support query string and json data in and out
 
 =head1 ENVIRONMENT VARIABLES
 
-These enviornment variables expose the control without changing the existing code.
+These enviornment variables expose the controls without changing the existing code.
 
 HTTP VARIABLES
 
@@ -156,7 +165,7 @@ has ssl_verify => (
 );
 
 sub _build_ssl_verify {
-    return _smart_or($ENV{SSL_VERIFY}, 0);
+    return _smart_or( $ENV{SSL_VERIFY}, 0 );
 }
 
 has retry => (
@@ -188,9 +197,9 @@ has retry_config => (
 
 sub _build_retry_config {
     return {
-        fail_response => _smart_or($ENV{RETRY_FAIL_RESPONSE}, 0),
+        fail_response => _smart_or( $ENV{RETRY_FAIL_RESPONSE}, 0 ),
         fail_status => $ENV{RETRY_FAIL_STATUS} || q{},
-        delay => _smart_or($ENV{RETRY_DELAY}, 5),
+        delay => _smart_or( $ENV{RETRY_DELAY}, 5 ),
     };
 }
 
@@ -269,9 +278,9 @@ sub send {
     my $base_url     = $self->base_url;
     my $url          = $base_url ? $base_url . $path : $path;
     my $req          = $self->_request( $method, $url, $data, $headers );
-    my $retry_count  = _smart_or($self->retry->{count}, 1);
+    my $retry_count  = _smart_or( $self->retry->{count}, 1 );
     my %retry_status = %{ $self->retry->{status} || {} };
-    my $retry_delay  = _smart_or($self->retry->{delay}, 5);
+    my $retry_delay  = _smart_or( $self->retry->{delay}, 5 );
     my %debug        = %{ $self->debug_flags || {} };
 
     my $response;
@@ -331,9 +340,6 @@ sub send {
     }
 
     return $self->last_response($response);
-## Please see file perltidy.ERR
-## Please see file perltidy.ERR
-## Please see file perltidy.ERR
 }
 
 sub json_response {
@@ -449,8 +455,10 @@ sub _basic_authenticator {
 
 sub _smart_or {
     my $default_value = shift;
-    my $or_value    = shift;
-    return defined($default_value) && length($default_value) ? $default_value : $or_value;
+    my $or_value      = shift;
+    return
+      defined($default_value)
+      && length($default_value) ? $default_value : $or_value;
 }
 
 1;
